@@ -6,17 +6,16 @@ use warnings;
 
 use base qw( WWW::Shorten::generic Exporter );
 our @EXPORT = qw(makeashorterlink makealongerlink);
-our $VERSION = '1.55';
+our ($VERSION) = q$Revision: 1.1 $ =~ /^ Revision: \s+ (\S+) \s+ $/x;
 
 use Carp;
-use URI;
 
-sub makeashorterlink ($;%)
+sub makeashorterlink ($;$$)
 {
     my $url = shift or croak 'No URL passed to makeashorterlink';
     my $ua = __PACKAGE__->ua();
     my ($nick,$pass) = @_;
-    my $snipurl = 'http://snipurl.com/teindex.php';
+    my $snipurl = 'http://snipurl.com/';
     my $resp = $ua->post($snipurl, [
 	link => $url,
 	alias => (defined $nick ? $nick : ''),
@@ -24,34 +23,34 @@ sub makeashorterlink ($;%)
 	]);
     return unless $resp->is_success;
     if ($resp->content =~ m!
-	<a \s+ href=['"] ([^'"]+) ['"][^>]*>
-	(http://sn(?:ip)?url\.com/\w+)
+	<a \s+ href=['"] ([^'"]+)  ['"][^>]*>
+	(\Qhttp://snurl.com/\E\w+)
 	</a>
-	!xm) {
+	!x) {
 	return $1;
     }
-    return undef;
 }
 
 sub makealongerlink ($)
 {
-    my $code = shift 
+    my $snipurl_url = shift 
 	or croak 'No SnipURL key / URL passed to makealongerlink';
     my $ua = __PACKAGE__->ua();
 
-    $code =~ s{^ http:// .* / }{}x;
-    my $snipurl_url = URI->new('http://snipurl.com/resolveurl');
-    $snipurl_url->query_form(
-	id => $code,
-    );
+    $snipurl_url = "http://snipurl.com/$snipurl_url"
+    unless $snipurl_url =~ m!^http://!i;
 
     my $resp = $ua->get($snipurl_url);
-    return undef unless $resp->is_success;
 
-    my $content = $resp->content;
-    return undef if $content eq 'ERROR';
-    my ($link) = $content =~ m! " ([^"]+) " !xi;
-    return $link;
+    return undef unless $resp->is_redirect;
+    my $url = $resp->header('Location');
+    {
+	$resp = $ua->get($url);
+	return $url unless $resp->is_redirect;
+	$url = $resp->header('Location');
+    }
+    return $url;
+
 }
 
 1;
@@ -70,14 +69,14 @@ WWW::Shorten::SnipURL - Perl interface to SnipURL.com
   use WWW::Shorten 'SnipURL';
 
   $short_url = makeashorterlink($long_url);
+  ($short_url,$password) = makeashorterlink($long_url);
 
   $long_url  = makealongerlink($short_url);
 
 =head1 DESCRIPTION
 
-A Perl interface to the web service SnipURL.com. SnipURL maintains a
-database of long URLs, each of which has a unique identifier or
-nickname. For more features, please visit http://snipurl.com/features
+A Perl interface to the web site snipurl.com.  SnipURL simply maintains
+a database of long URLs, each of which has a unique identifier.
 
 The function C<makeashorterlink> will call the SnipURL web site passing it
 your long URL and will return the shorter SnipURL version. If used in a
@@ -93,17 +92,10 @@ If anything goes wrong, then either function will return C<undef>.
 
 makeashorterlink, makealongerlink
 
-=head1 BUGS, REQUESTS, COMMENTS
+=head1 BUGS
 
-Please report any requests, suggestions or bugs via the system at
-L<http://rt.cpan.org/>, or email E<lt>bug-WWW-Shorten@rt.cpan.orgE<gt>.
-This makes it much easier for me to track things and thus means
-your problem is less likely to be neglected.
-
-=head1 THANKS
-
-Shashank Tripathi <shank@shank.com> for providing both
-SnipURL.com and advice on the module.
+Please report bugs at <bug-www-shorten@rt.cpan.org>
+or via the web interface at L<http://rt.cpan.org>
 
 =head1 AUTHOR
 
